@@ -1,4 +1,3 @@
-mod helpers;
 mod msg;
 mod query;
 mod receiver;
@@ -6,11 +5,11 @@ mod traits;
 
 pub use cw0::Expiration;
 
-pub use crate::helpers::Cw721Contract;
 pub use crate::msg::Cw721ExecuteMsg;
 pub use crate::query::{
-    AllNftInfoResponse, Approval, ApprovedForAllResponse, ContractInfoResponse, Cw721QueryMsg,
-    NftInfoResponse, NumTokensResponse, OwnerOfResponse, TokensResponse,
+    AllNftInfoResponse, Approval, ApprovalResponse, ApprovalsResponse, ContractInfoResponse,
+    Cw721QueryMsg, NftInfoResponse, NumTokensResponse, OperatorsResponse, OwnerOfResponse,
+    TokensResponse,
 };
 pub use crate::receiver::Cw721ReceiveMsg;
 pub use crate::traits::{CustomMsg, Cw721, Cw721Execute, Cw721Query};
