@@ -13,6 +13,11 @@ pub enum Cw721QueryMsg {
         /// unset or false will filter out expired approvals, you must set to true to see them
         include_expired: Option<bool>,
     },
+
+    /// Return operator that can access all of the owner's tokens.
+    /// Return type: `ApprovedResponse`
+    Approved { owner: String, operator: String },
+
     /// List all operators that can access all of the owner's tokens.
     /// Return type: `ApprovedForAllResponse`
     ApprovedForAll {
@@ -75,7 +80,17 @@ pub struct Approval {
 }
 
 #[derive(Serialize, Deserialize, Clone, PartialEq, JsonSchema, Debug)]
-pub struct ApprovedForAllResponse {
+pub struct ApprovalResponse {
+    pub approval: Approval,
+}
+
+#[derive(Serialize, Deserialize, Clone, PartialEq, JsonSchema, Debug)]
+pub struct ApprovalsResponse {
+    pub approvals: Vec<Approval>,
+}
+
+#[derive(Serialize, Deserialize, Clone, PartialEq, JsonSchema, Debug)]
+pub struct OperatorsResponse {
     pub operators: Vec<Approval>,
 }
 
